@@ -47,7 +47,7 @@ module BasicPrelude
   , BasicPrelude.sum
   , BasicPrelude.product
     -- ** Text for Read and Show operations
-  , show
+  , tshow
   , fromShow
   , read
   , readIO
@@ -79,9 +79,8 @@ module BasicPrelude
   , Prelude.gcd
   , Prelude.lcm
     -- ** Show and Read
+  , Prelude.Show (..)
   , Prelude.ShowS
-  , Prelude.showsPrec
-  , Prelude.showList
   , Prelude.shows
   , Prelude.showChar
   , Prelude.showString
@@ -174,17 +173,19 @@ intercalate xs xss = mconcat (Data.List.intersperse xs xss)
 
 
 -- | Compute the sum of a finite list of numbers.
-sum :: Num a => [a] -> a
+sum :: (Foldable f, Num a) => f a -> a
 sum = Data.Foldable.foldl' (+) 0
 
 -- | Compute the product of a finite list of numbers.
-product :: Num a => [a] -> a
+product :: (Foldable f, Num a) => f a -> a
 product = Data.Foldable.foldl' (*) 1
 
 
 -- | Convert a value to readable Text
-show :: Show a => a -> Text
-show = Text.pack . Prelude.show
+--
+-- @since 0.6.0
+tshow :: Show a => a -> Text
+tshow = Text.pack . Prelude.show
 
 -- | Convert a value to readable IsString
 --
